==> selenium-selenium-4.35.0.gh.tar.gz: selenium-selenium-4.35.0/dotnet/src/webdriver/BiDi/Browser/CreateUserContextCommand.cs <==
// <copyright file="CreateUserContextCommand.cs" company="Selenium Committers">
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
// </copyright>

using OpenQA.Selenium.BiDi.Communication;

namespace OpenQA.Selenium.BiDi.Browser;

internal sealed class CreateUserContextCommand(CreateUserContextCommandParameters @params)
    : Command<CreateUserContextCommandParameters, UserContextInfo>(@params, "browser.createUserContext");

internal sealed record CreateUserContextCommandParameters(bool? AcceptInsecureCerts, Session.ProxyConfiguration? Proxy, Session.UserPromptHandler? UnhandledPromptBehavior) : CommandParameters;

public sealed class CreateUserContextOptions : CommandOptions
{
    public bool? AcceptInsecureCerts { get; set; }

    public Session.ProxyConfiguration? Proxy { get; set; }

    public Session.UserPromptHandler? UnhandledPromptBehavior { get; set; }
}

==> selenium-selenium-4.36.0.gh.tar.gz: selenium-selenium-4.36.0/dotnet/src/webdriver/BiDi/Browser/CreateUserContextCommand.cs <==
// <copyright file="CreateUserContextCommand.cs" company="Selenium Committers">
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
// </copyright>

using OpenQA.Selenium.BiDi.Communication;

namespace OpenQA.Selenium.BiDi.Browser;

internal sealed class CreateUserContextCommand(CreateUserContextParameters @params)
    : Command<CreateUserContextParameters, UserContextInfo>(@params, "browser.createUserContext");

internal sealed record CreateUserContextParameters(bool? AcceptInsecureCerts, Session.ProxyConfiguration? Proxy, Session.UserPromptHandler? UnhandledPromptBehavior) : Parameters;

public sealed class CreateUserContextOptions : CommandOptions
{
    public bool? AcceptInsecureCerts { get; set; }

    public Session.ProxyConfiguration? Proxy { get; set; }

    public Session.UserPromptHandler? UnhandledPromptBehavior { get; set; }
}
